networkinference.utils
======================

Classes
-------

.. autosummary::
    :toctree: _autosummary
    :template: custom-class-template.rst
    :recursive:

    networkinference.utils.tools.FakeData

Functions
---------

.. autosummary::
    :toctree: _autosummary
    :template: custom-module-template.rst
    :recursive:

    networkinference.utils.tools.adjrownorm
    networkinference.utils.tools.nhbr_mean
